Class: Faker::Music::SmashingPumpkins
- Defined in:
- lib/faker/music/smashing_pumpkins.rb
Constant Summary
Constants inherited from Base
Base::LLetters, Base::Letters, Base::NOT_GIVEN, Base::Numbers, Base::ULetters
Class Method Summary collapse
-
.album ⇒ String
Produces the name of an album by the Smashing Pumpkins.
-
.lyric ⇒ String
Produces a random Smashing Pumpkins song lyric.
-
.musician ⇒ String
Produces the name of a member of the Smashing Pumpkins (current and former).
-
.song ⇒ String
Produces the name of a song by the Smashing Pumpkins.
Methods inherited from Base
bothify, disable_enforce_available_locales, fetch, fetch_all, flexible, generate, letterify, method_missing, numerify, parse, rand, rand_in_range, regexify, resolve, respond_to_missing?, sample, shuffle, shuffle!, translate, unique, with_locale
Class Method Details
.album ⇒ String
Produces the name of an album by the Smashing Pumpkins.
29 30 31 |
# File 'lib/faker/music/smashing_pumpkins.rb', line 29 def album fetch('smashing_pumpkins.albums') end |
.lyric ⇒ String
Produces a random Smashing Pumpkins song lyric.
43 44 45 |
# File 'lib/faker/music/smashing_pumpkins.rb', line 43 def lyric fetch('smashing_pumpkins.lyric') end |
.musician ⇒ String
Produces the name of a member of the Smashing Pumpkins (current and former)
16 17 18 |
# File 'lib/faker/music/smashing_pumpkins.rb', line 16 def musician fetch('smashing_pumpkins.musicians') end |
.song ⇒ String
Produces the name of a song by the Smashing Pumpkins.
56 57 58 |
# File 'lib/faker/music/smashing_pumpkins.rb', line 56 def song fetch('smashing_pumpkins.songs') end |